nth_weekday
===========

.. image:: https://img.shields.io/pypi/v/nth_weekday.svg
    :target: https://pypi.python.org/pypi/nth_weekday
    :alt: Latest PyPI version



Usage
-----

Installation
------------

Requirements
^^^^^^^^^^^^

Compatibility
-------------

Licence
-------

Authors
-------

`nth_weekday` was written by `fx-kirin <fx.kirin@gmail.com>`_.
